# Collaborative Drawing

![drawing-demo](https://user-images.githubusercontent.com/5553757/189190756-21c2bc61-1816-488e-b2cd-bc910fece6d9.gif)

A basic collaborative drawing application using Ypy and WebSockets. Left click on the canvas to leave a mark.

## Getting Started

1. Install Python dependencies:

```
pip install -r requirements.txt
```

2. Run the demo

```
python demo.py
```
